==> scanbot_sdk-2.3.0.tar.gz: lib/scanbot_sdk_models.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

import 'common_data.dart';

part 'scanbot_sdk_models.g.dart';

/// Scanbot SDK initialization config parameters.
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class ScanbotSdkConfig {
  /// Your license key for the Scanbot SDK.
  String licenseKey;

  /// Optional image quality value. Defines the quality factor of JPEG images.
  /// The value must be between 1 and 100, where 100 means maximum quality and
  /// largest file size. The default value is 80 which is a good compromise
  /// between image file size and document legibility.
  int imageQuality;

  /// Optional image format value in which format all pages will be stored.
  ImageFormat imageFormat;

  /// Optional logging flag. While it may be useful for development,
  /// consider switching logging OFF in production builds for security and performance reasons!
  bool loggingEnabled;

  /// Optional custom storage base directory. Can be nil.
  String storageBaseDirectory;

  /// Callback function to get info about problems with license key
  /// or concrete feature that is not available for usage
  @JsonKey(ignore: true)
  Function(Status, SdkFeature) licenseErrorHandler;

  /// Optional document detector mode:
  /// EDGE_BASED - default implementation, based on classical edge detection approach
  /// ML_BASED - new Machine Learning based approach (requires iOS 11.2+)
  DocumentDetectorMode documentDetectorMode;

  EncryptionParameters encryptionParameters;

  ScanbotSdkConfig(
      {this.licenseKey,
      this.imageQuality,
      this.imageFormat,
      this.loggingEnabled,
      this.storageBaseDirectory,
      this.licenseErrorHandler,
      this.encryptionParameters,
      this.documentDetectorMode});

  factory ScanbotSdkConfig.fromJson(Map<String, dynamic> json) =>
      _$ScanbotSdkConfigFromJson(json);

  Map<String, dynamic> toJson() => _$ScanbotSdkConfigToJson(this);
}

/// Scanbot SDK license status.
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class SdkLicenseStatus {
  /// Indicates whether the current license key is valid or not.
  bool isLicenseValid;
  Status status;
  @JsonKey(fromJson: dateFromString)
  DateTime expirationDate;

  SdkLicenseStatus(this.isLicenseValid);

  factory SdkLicenseStatus.fromJson(Map<String, dynamic> json) =>
      _$SdkLicenseStatusFromJson(json);

  Map<String, dynamic> toJson() => _$SdkLicenseStatusToJson(this);
}

enum DocumentDetectorMode { EDGE_BASED, ML_BASED }

enum Status {
  StatusOkay,
  StatusTrial,
  StatusFailureNotSet,
  StatusFailureCorrupted,
  StatusFailureWrongOS,
  StatusFailureAppIDMismatch,
  StatusFailureExpired
}
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class EncryptionParameters {
  /// A secure password or passphrase to derive the AES key for encryption/decryption
  String password;

  /// Length of the key in AES encryption - 128 or 256 bits
  FileEncryptionMode mode;

  EncryptionParameters({this.password, this.mode});

  factory EncryptionParameters.fromJson(Map<String, dynamic> json) =>
      _$EncryptionParametersFromJson(json);

  Map<String, dynamic> toJson() => _$EncryptionParametersToJson(this);
}

enum FileEncryptionMode { AES128, AES256 }

enum SdkFeature {
  NoSdkFeature,
  PayformDetection,
  EdgeDetection,
  EdgeDetectionUI,
  ImageProcessing,
  OCR,
  DataIntelligence,
  PDFCreation,
  CloudUpload,
  CreditCardRecognition,
  Barcode,
  W2Detection,
  Cheque,
  InvoiceDetection,
  MRZRecognition,
  DisabilityCertRecognition,
  MultipleObjectsDetection,
  TextOrientationDetection,
  EHICRecognition,
}

@JsonSerializable(nullable: true)
class SdkLicenseException {
  Status status;
  SdkFeature feature;

  SdkLicenseException(this.status);

  factory SdkLicenseException.fromJson(Map<String, dynamic> json) =>
      _$SdkLicenseExceptionFromJson(json);

  Map<String, dynamic> toJson() => _$SdkLicenseExceptionToJson(this);
}

==> scanbot_sdk-2.4.1.tar.gz: lib/scanbot_sdk_models.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

import 'common_data.dart';

part 'scanbot_sdk_models.g.dart';

/// Scanbot SDK initialization config parameters.
@JsonSerializable(
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class ScanbotSdkConfig {
  /// Your license key for the Scanbot SDK.
  String? licenseKey;

  /// Optional image quality value. Defines the quality factor of JPEG images.
  /// The value must be between 1 and 100, where 100 means maximum quality and
  /// largest file size. The default value is 80 which is a good compromise
  /// between image file size and document legibility.
  int? imageQuality;

  /// Optional image format value in which format all pages will be stored.
  ImageFormat? imageFormat;

  /// Optional logging flag. While it may be useful for development,
  /// consider switching logging OFF in production builds for security and performance reasons!
  bool? loggingEnabled;

  /// Optional custom storage base directory. Can be nil.
  String? storageBaseDirectory;

  /// Callback function to get info about problems with license key
  /// or concrete feature that is not available for usage
  @JsonKey(ignore: true)
  Function(Status, SdkFeature?)? licenseErrorHandler;

  /// Optional document detector mode:
  /// EDGE_BASED - default implementation, based on classical edge detection approach
  /// ML_BASED - new Machine Learning based approach (requires iOS 11.2+)
  DocumentDetectorMode? documentDetectorMode;

  EncryptionParameters? encryptionParameters;

  ScanbotSdkConfig(
      {this.licenseKey,
      this.imageQuality,
      this.imageFormat,
      this.loggingEnabled,
      this.storageBaseDirectory,
      this.licenseErrorHandler,
      this.encryptionParameters,
      this.documentDetectorMode});

  factory ScanbotSdkConfig.fromJson(Map<String, dynamic> json) =>
      _$ScanbotSdkConfigFromJson(json);

  Map<String, dynamic> toJson() => _$ScanbotSdkConfigToJson(this);
}

/// Scanbot SDK license status.
@JsonSerializable(
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class SdkLicenseStatus {
  /// Indicates whether the current license key is valid or not.
  bool isLicenseValid;
  Status? status;
  @JsonKey(fromJson: dateFromString)
  DateTime? expirationDate;

  SdkLicenseStatus(this.isLicenseValid);

  factory SdkLicenseStatus.fromJson(Map<String, dynamic> json) =>
      _$SdkLicenseStatusFromJson(json);

  Map<String, dynamic> toJson() => _$SdkLicenseStatusToJson(this);
}

enum DocumentDetectorMode { EDGE_BASED, ML_BASED }

enum Status {
  StatusOkay,
  StatusTrial,
  StatusFailureNotSet,
  StatusFailureCorrupted,
  StatusFailureWrongOS,
  StatusFailureAppIDMismatch,
  StatusFailureExpired
}

@JsonSerializable(
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class EncryptionParameters {
  /// A secure password or passphrase to derive the AES key for encryption/decryption
  String password;

  /// Length of the key in AES encryption - 128 or 256 bits
  FileEncryptionMode mode;

  EncryptionParameters(
      {this.password = '', this.mode = FileEncryptionMode.AES256});

  factory EncryptionParameters.fromJson(Map<String, dynamic> json) =>
      _$EncryptionParametersFromJson(json);

  Map<String, dynamic> toJson() => _$EncryptionParametersToJson(this);
}

enum FileEncryptionMode { AES128, AES256 }

enum SdkFeature {
  NoSdkFeature,
  PayformDetection,
  EdgeDetection,
  EdgeDetectionUI,
  ImageProcessing,
  OCR,
  DataIntelligence,
  PDFCreation,
  CloudUpload,
  CreditCardRecognition,
  Barcode,
  W2Detection,
  Cheque,
  InvoiceDetection,
  MRZRecognition,
  DisabilityCertRecognition,
  MultipleObjectsDetection,
  TextOrientationDetection,
  EHICRecognition,
}

@JsonSerializable()
class SdkLicenseException {
  Status status;
  SdkFeature? feature;

  SdkLicenseException(this.status);

  factory SdkLicenseException.fromJson(Map<String, dynamic> json) =>
      _$SdkLicenseExceptionFromJson(json);

  Map<String, dynamic> toJson() => _$SdkLicenseExceptionToJson(this);
}
